==> wawa-proxy-api-0.0.9-20171127.054039-54-sources.jar: cn/com/wawa/proxy/api/protocol/MQMessageBody.java <==
package cn.com.wawa.proxy.api.protocol;

import java.io.Serializable;
import java.util.List;

/**
 * Created by danke on 2017/11/27.
 * mq消息体,用于接收业务服务器mq消息
 */
public class MQMessageBody implements Serializable {

    /**
     * 用户id
     */
    private Long useId;
    /**
     * 娃娃机id
     */
    private Long wawaId;
    /**
     * 推送消息
     */
    private String message;
    /**
     * 娃娃机状态  1-空闲 2-热玩
     */
    private int wawaStatus;
    /**
     * 消息类型,1-聊天消息通知 2-中奖通知 3-娃娃机状态通知
     */
    private int messageType;
    /**
     * 订单id
     */
    private String orderId;
    /**
     * 需要推送的客户端id
     */
    private List<Long> pushUseIds;

    public Long getUseId() {
        return useId;
    }

    public void setUseId(Long useId) {
        this.useId = useId;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public int getWawaStatus() {
        return wawaStatus;
    }

    public void setWawaStatus(int wawaStatus) {
        this.wawaStatus = wawaStatus;
    }

    public int getMessageType() {
        return messageType;
    }

    public void setMessageType(int messageType) {
        this.messageType = messageType;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public List<Long> getPushUseIds() {
        return pushUseIds;
    }

    public void setPushUseIds(List<Long> pushUseIds) {
        this.pushUseIds = pushUseIds;
    }
}

==> wawa-proxy-api-0.0.9-20171127.093842-55-sources.jar: cn/com/wawa/proxy/api/protocol/MQMessageBody.java <==
package cn.com.wawa.proxy.api.protocol;

import java.io.Serializable;
import java.util.List;

/**
 * Created by danke on 2017/11/27.
 * mq消息体,用于接收业务服务器mq消息
 */
public class MQMessageBody implements Serializable {

    /**
     * 用户id
     */
    private Long useId;
    /**
     * 娃娃机id
     */
    private Long wawaId;
    /**
     * 推送消息
     */
    private String message;
    /**
     * 娃娃机状态  1-空闲 2-热玩
     */
    private int wawaStatus;
    /**
     * 消息类型,1-聊天消息通知 2-中奖通知 3-娃娃机状态通知
     */
    private int messageType;
    /**
     * 订单id
     */
    private String orderId;
    /**
     * 需要推送的客户端id
     */
    private List<Long> pushUseIds;

    public Long getUseId() {
        return useId;
    }

    public void setUseId(Long useId) {
        this.useId = useId;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public int getWawaStatus() {
        return wawaStatus;
    }

    public void setWawaStatus(int wawaStatus) {
        this.wawaStatus = wawaStatus;
    }

    public int getMessageType() {
        return messageType;
    }

    public void setMessageType(int messageType) {
        this.messageType = messageType;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public List<Long> getPushUseIds() {
        return pushUseIds;
    }

    public void setPushUseIds(List<Long> pushUseIds) {
        this.pushUseIds = pushUseIds;
    }

    @Override
    public String toString() {
        return "MQMessageBody{" +
                "useId=" + useId +
                ", wawaId=" + wawaId +
                ", message='" + message + '\'' +
                ", wawaStatus=" + wawaStatus +
                ", messageType=" + messageType +
                ", orderId='" + orderId + '\'' +
                ", pushUseIds=" + pushUseIds +
                '}';
    }
}
